package de.rmdir.ms2debounce;

import android.app.Activity;
import android.app.Dialog;
import android.app.AlertDialog;
import android.os.Bundle;
import android.content.Intent;
import android.content.DialogInterface;
import android.widget.TextView;
import android.widget.EditText;
import android.widget.Button;
import android.widget.CheckBox;
import android.view.View;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;

public class MS2Debounce extends Activity
{
	private DebounceModuleHelper module;

	public MS2Debounce()
	{
		super();
		module = new DebounceModuleHelper(this);
	}

	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		//if (!module.isLoaded()) {
		//	module.loadModule();
		//}

		setContentView(R.layout.main);
		updateUI();
	}

	private void updateUI() {
		disableUI();

		boolean loaded = module.isLoaded();
		boolean safe_to_load = module.is_safe_to_load();

		TextView text = (TextView)findViewById(R.id.text);
		text.setText("Current status:\n\nModule loaded: " + loaded + "\ndebounce_delay: " + module.getDelay() + "ms\nsafe_to_load: " + safe_to_load);

		//EditText textDelay = (EditText)findViewById(R.id.debounce_delay);
		//textDelay.setText(module.getSavedDelay());

		Button reload = (Button)findViewById(R.id.reload);
		if (loaded) {
			reload.setEnabled(true);
		} else {
			reload.setEnabled(false);
		}

		Button load = (Button)findViewById(R.id.load);
		if (loaded) {
			load.setEnabled(false);
		} else {
			load.setEnabled(true);
		}

		Button unload = (Button)findViewById(R.id.unload);
		if (loaded) {
			unload.setEnabled(true);
		} else {
			unload.setEnabled(false);
		}

		CheckBox on_boot = (CheckBox)findViewById(R.id.on_boot);
		on_boot.setChecked(module.get_on_boot());
		if (safe_to_load) {
			on_boot.setEnabled(true);
		} else {
			on_boot.setEnabled(false);
		}
	}

	private void disableUI() {
		Button reload = (Button)findViewById(R.id.reload);
		reload.setEnabled(false);

		Button load = (Button)findViewById(R.id.load);
		load.setEnabled(false);

		Button unload = (Button)findViewById(R.id.unload);
		unload.setEnabled(false);

		CheckBox on_boot = (CheckBox)findViewById(R.id.on_boot);
		on_boot.setEnabled(false);
	}

	public void loadModule(View view) {
		disableUI();
		if (!module.isLoaded()) {
			module.loadModule();
		}
		updateUI();
	}

	public void unloadModule(View view) {
		disableUI();
		if (module.isLoaded()) {
			module.unloadModule();
		}
		updateUI();
	}

	public void reloadModule(View view) {
		disableUI();
		if (module.isLoaded()) {
			module.unloadModule();
		}
		if (!module.isLoaded()) {
			module.loadModule();
		}
		updateUI();
	}

	public void toggle_on_boot(View view) {
		CheckBox on_boot = (CheckBox)view;

		module.set_on_boot(on_boot.isChecked());
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
			case R.id.about:
				showDialog(42);
				return true;
			default:
				return super.onOptionsItemSelected(item);
		}
	}

	protected Dialog onCreateDialog(int id) {
		Dialog dlg = null;

		AlertDialog.Builder about = new AlertDialog.Builder(this);
		about.setMessage("Milestone 2 Debounce\n\n(C) 2011 Michael Gernoth <michael@gernoth.net>\n\nThis program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation version 2 of the License.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA")
			.setCancelable(true)
			.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int id) {
					dialog.cancel();
				}
			});
		dlg = about.create();

		return dlg;
	}
}
